@@ -18,7 +18,12 @@ from typing import Any, Dict, Mapping, Type
 from botocore.client import BaseClient, ClientMeta
 
 from .literals import AlternateContactTypeType
-from .type_defs import EmptyResponseMetadataTypeDef, GetAlternateContactResponseTypeDef
+from .type_defs import (
+    ContactInformationTypeDef,
+    EmptyResponseMetadataTypeDef,
+    GetAlternateContactResponseTypeDef,
+    GetContactInformationResponseTypeDef,
+)
 
 __all__ = ("AccountClient",)
 
@@ -65,6 +70,14 @@ class AccountClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_account/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/account.html#Account.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_account/client/#close)
+        """
+
     def delete_alternate_contact(
         self, *, AlternateContactType: AlternateContactTypeType, AccountId: str = ...
     ) -> EmptyResponseMetadataTypeDef:
@@ -100,6 +113,16 @@ class AccountClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_account/client/#get_alternate_contact)
         """
 
+    def get_contact_information(
+        self, *, AccountId: str = ...
+    ) -> GetContactInformationResponseTypeDef:
+        """
+        Retrieves the primary contact information of an Amazon Web Services account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/account.html#Account.Client.get_contact_information)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_account/client/#get_contact_information)
+        """
+
     def put_alternate_contact(
         self,
         *,
@@ -117,3 +140,13 @@ class AccountClient(BaseClient):
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/account.html#Account.Client.put_alternate_contact)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_account/client/#put_alternate_contact)
         """
+
+    def put_contact_information(
+        self, *, ContactInformation: ContactInformationTypeDef, AccountId: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        Updates the primary contact information of an Amazon Web Services account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/account.html#Account.Client.put_contact_information)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_account/client/#put_contact_information)
+        """
